==> zio-aws-ec2_2.13-5.17.197.1-sources.jar: zio/aws/ec2/model/NetworkInterfaceAttachment.scala <==
package zio.aws.ec2.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{Integer, DateTime}
import scala.jdk.CollectionConverters._
final case class NetworkInterfaceAttachment(
    attachTime: Optional[DateTime] = Optional.Absent,
    attachmentId: Optional[String] = Optional.Absent,
    deleteOnTermination: Optional[Boolean] = Optional.Absent,
    deviceIndex: Optional[Integer] = Optional.Absent,
    networkCardIndex: Optional[Integer] = Optional.Absent,
    instanceId: Optional[String] = Optional.Absent,
    instanceOwnerId: Optional[String] = Optional.Absent,
    status: Optional[zio.aws.ec2.model.AttachmentStatus] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.NetworkInterfaceAttachment = {
    import NetworkInterfaceAttachment.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceAttachment
      .builder()
      .optionallyWith(attachTime.map(value => DateTime.unwrap(value): Instant))(
        _.attachTime
      )
      .optionallyWith(attachmentId.map(value => value: java.lang.String))(
        _.attachmentId
      )
      .optionallyWith(
        deleteOnTermination.map(value => value: java.lang.Boolean)
      )(_.deleteOnTermination)
      .optionallyWith(deviceIndex.map(value => value: java.lang.Integer))(
        _.deviceIndex
      )
      .optionallyWith(networkCardIndex.map(value => value: java.lang.Integer))(
        _.networkCardIndex
      )
      .optionallyWith(instanceId.map(value => value: java.lang.String))(
        _.instanceId
      )
      .optionallyWith(instanceOwnerId.map(value => value: java.lang.String))(
        _.instanceOwnerId
      )
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.NetworkInterfaceAttachment.ReadOnly =
    zio.aws.ec2.model.NetworkInterfaceAttachment.wrap(buildAwsValue())
}
object NetworkInterfaceAttachment {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceAttachment
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.NetworkInterfaceAttachment =
      zio.aws.ec2.model.NetworkInterfaceAttachment(
        attachTime.map(value => value),
        attachmentId.map(value => value),
        deleteOnTermination.map(value => value),
        deviceIndex.map(value => value),
        networkCardIndex.map(value => value),
        instanceId.map(value => value),
        instanceOwnerId.map(value => value),
        status.map(value => value)
      )
    def attachTime: Optional[DateTime]
    def attachmentId: Optional[String]
    def deleteOnTermination: Optional[Boolean]
    def deviceIndex: Optional[Integer]
    def networkCardIndex: Optional[Integer]
    def instanceId: Optional[String]
    def instanceOwnerId: Optional[String]
    def status: Optional[zio.aws.ec2.model.AttachmentStatus]
    def getAttachTime: ZIO[Any, AwsError, DateTime] =
      AwsError.unwrapOptionField("attachTime", attachTime)
    def getAttachmentId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("attachmentId", attachmentId)
    def getDeleteOnTermination: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("deleteOnTermination", deleteOnTermination)
    def getDeviceIndex: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("deviceIndex", deviceIndex)
    def getNetworkCardIndex: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("networkCardIndex", networkCardIndex)
    def getInstanceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceId", instanceId)
    def getInstanceOwnerId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceOwnerId", instanceOwnerId)
    def getStatus: ZIO[Any, AwsError, zio.aws.ec2.model.AttachmentStatus] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceAttachment
  ) extends zio.aws.ec2.model.NetworkInterfaceAttachment.ReadOnly {
    override val attachTime: Optional[DateTime] = zio.aws.core.internal
      .optionalFromNullable(impl.attachTime())
      .map(value => zio.aws.ec2.model.primitives.DateTime(value))
    override val attachmentId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.attachmentId())
      .map(value => value: String)
    override val deleteOnTermination: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.deleteOnTermination())
      .map(value => value: Boolean)
    override val deviceIndex: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.deviceIndex())
      .map(value => value: Integer)
    override val networkCardIndex: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.networkCardIndex())
      .map(value => value: Integer)
    override val instanceId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceId())
      .map(value => value: String)
    override val instanceOwnerId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceOwnerId())
      .map(value => value: String)
    override val status: Optional[zio.aws.ec2.model.AttachmentStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.ec2.model.AttachmentStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceAttachment
  ): zio.aws.ec2.model.NetworkInterfaceAttachment.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.20.17.1-sources.jar: zio/aws/ec2/model/NetworkInterfaceAttachment.scala <==
package zio.aws.ec2.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{Integer, DateTime}
import scala.jdk.CollectionConverters._
final case class NetworkInterfaceAttachment(
    attachTime: Optional[DateTime] = Optional.Absent,
    attachmentId: Optional[String] = Optional.Absent,
    deleteOnTermination: Optional[Boolean] = Optional.Absent,
    deviceIndex: Optional[Integer] = Optional.Absent,
    networkCardIndex: Optional[Integer] = Optional.Absent,
    instanceId: Optional[String] = Optional.Absent,
    instanceOwnerId: Optional[String] = Optional.Absent,
    status: Optional[zio.aws.ec2.model.AttachmentStatus] = Optional.Absent,
    enaSrdSpecification: Optional[
      zio.aws.ec2.model.AttachmentEnaSrdSpecification
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.NetworkInterfaceAttachment = {
    import NetworkInterfaceAttachment.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceAttachment
      .builder()
      .optionallyWith(attachTime.map(value => DateTime.unwrap(value): Instant))(
        _.attachTime
      )
      .optionallyWith(attachmentId.map(value => value: java.lang.String))(
        _.attachmentId
      )
      .optionallyWith(
        deleteOnTermination.map(value => value: java.lang.Boolean)
      )(_.deleteOnTermination)
      .optionallyWith(deviceIndex.map(value => value: java.lang.Integer))(
        _.deviceIndex
      )
      .optionallyWith(networkCardIndex.map(value => value: java.lang.Integer))(
        _.networkCardIndex
      )
      .optionallyWith(instanceId.map(value => value: java.lang.String))(
        _.instanceId
      )
      .optionallyWith(instanceOwnerId.map(value => value: java.lang.String))(
        _.instanceOwnerId
      )
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(enaSrdSpecification.map(value => value.buildAwsValue()))(
        _.enaSrdSpecification
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.NetworkInterfaceAttachment.ReadOnly =
    zio.aws.ec2.model.NetworkInterfaceAttachment.wrap(buildAwsValue())
}
object NetworkInterfaceAttachment {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceAttachment
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.NetworkInterfaceAttachment =
      zio.aws.ec2.model.NetworkInterfaceAttachment(
        attachTime.map(value => value),
        attachmentId.map(value => value),
        deleteOnTermination.map(value => value),
        deviceIndex.map(value => value),
        networkCardIndex.map(value => value),
        instanceId.map(value => value),
        instanceOwnerId.map(value => value),
        status.map(value => value),
        enaSrdSpecification.map(value => value.asEditable)
      )
    def attachTime: Optional[DateTime]
    def attachmentId: Optional[String]
    def deleteOnTermination: Optional[Boolean]
    def deviceIndex: Optional[Integer]
    def networkCardIndex: Optional[Integer]
    def instanceId: Optional[String]
    def instanceOwnerId: Optional[String]
    def status: Optional[zio.aws.ec2.model.AttachmentStatus]
    def enaSrdSpecification
        : Optional[zio.aws.ec2.model.AttachmentEnaSrdSpecification.ReadOnly]
    def getAttachTime: ZIO[Any, AwsError, DateTime] =
      AwsError.unwrapOptionField("attachTime", attachTime)
    def getAttachmentId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("attachmentId", attachmentId)
    def getDeleteOnTermination: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("deleteOnTermination", deleteOnTermination)
    def getDeviceIndex: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("deviceIndex", deviceIndex)
    def getNetworkCardIndex: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("networkCardIndex", networkCardIndex)
    def getInstanceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceId", instanceId)
    def getInstanceOwnerId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceOwnerId", instanceOwnerId)
    def getStatus: ZIO[Any, AwsError, zio.aws.ec2.model.AttachmentStatus] =
      AwsError.unwrapOptionField("status", status)
    def getEnaSrdSpecification: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.AttachmentEnaSrdSpecification.ReadOnly
    ] = AwsError.unwrapOptionField("enaSrdSpecification", enaSrdSpecification)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceAttachment
  ) extends zio.aws.ec2.model.NetworkInterfaceAttachment.ReadOnly {
    override val attachTime: Optional[DateTime] = zio.aws.core.internal
      .optionalFromNullable(impl.attachTime())
      .map(value => zio.aws.ec2.model.primitives.DateTime(value))
    override val attachmentId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.attachmentId())
      .map(value => value: String)
    override val deleteOnTermination: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.deleteOnTermination())
      .map(value => value: Boolean)
    override val deviceIndex: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.deviceIndex())
      .map(value => value: Integer)
    override val networkCardIndex: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.networkCardIndex())
      .map(value => value: Integer)
    override val instanceId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceId())
      .map(value => value: String)
    override val instanceOwnerId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceOwnerId())
      .map(value => value: String)
    override val status: Optional[zio.aws.ec2.model.AttachmentStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.ec2.model.AttachmentStatus.wrap(value))
    override val enaSrdSpecification
        : Optional[zio.aws.ec2.model.AttachmentEnaSrdSpecification.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.enaSrdSpecification())
        .map(value =>
          zio.aws.ec2.model.AttachmentEnaSrdSpecification.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceAttachment
  ): zio.aws.ec2.model.NetworkInterfaceAttachment.ReadOnly = new Wrapper(impl)
}
